==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Downloads/language/lang-arabic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","");
define("_PREVIOUS"," ");
define("_NEXT"," ");
define("_CATEGORY","");
define("_CATEGORIES","");
define("_LVOTES","");
define("_TOTALVOTES"," :");
define("_THEREARE"," ");
define("_NOMATCHES","   ");
define("_SCOMMENTS","");
define("_UNKNOWN"," ");
define("_DOWNLOADS","");
define("_FILESIZE"," ");
define("_VERSION","");
define("_DESCRIPTION","");
define("_AUTHOR"," ");
define("_HOMEPAGE","");
define("_DOWNLOADNOW","  !");
define("_FILEURL"," ");
define("_ADDDOWNLOAD"," ");
define("_DOWNLOADSMAIN","  ");
define("_DOWNLOADCOMMENTS","  ");
define("_DOWNLOADSMAINCAT","  ");
define("_ADDADOWNLOAD","  ");
define("_DOWNLOADSNOTUSER1","         .");
define("_DOWNLOADSNOTUSER2","      .");
define("_DOWNLOADSNOTUSER3","   .");
define("_DOWNLOADSNOTUSER4","       ڿ");
define("_DOWNLOADSNOTUSER5","       ,");
define("_DOWNLOADSNOTUSER6","          .");
define("_DOWNLOADSNOTUSER7","     .");
define("_DOWNLOADSNOTUSER8","<a href=\"modules.php?name=Your_Account\"> </a>");
define("_DOWNLOADALREADYEXT",":       !");
define("_DOWNLOADNOTITLE",":      !");
define("_DOWNLOADNOURL",":    !");
define("_DOWNLOADNODESC",":    !");
define("_DOWNLOADRECEIVED","!     ");
define("_CHECKFORIT","   .      .");
define("_NEWDOWNLOADS"," ");
define("_TOTALNEWDOWNLOADS","  ");
define("_TRATEDDOWNLOADS","  ");
define("_SORTDOWNLOADSBY","  ");
define("_DOWNLOADPROFILE"," ");
define("_DOWNLOADRATINGDET","  ");
define("_EDITTHISDOWNLOAD","  ");
define("_DOWNLOADRATING"," ");
define("_PROMOTE02","One way to download to the rating form is through a simple text download:");
define("_PROMOTE03","If you're looking for a little more than a basic text download, you may wish to use a small button download:");
define("_PROMOTE04","If you cheat on this, we'll remove your download. Having said that, here is what the current remote rating form looks like.");
define("_DOWNLOADVOTE","!");
define("_REQUESTDOWNLOADMOD","Request Download Modification");
define("_DOWNLOADID","Download ID");
define("_DATE","");
define("_TO","");
define("_NEW","");
define("_POPULAR","");
define("_TOPRATED"," ");
define("_ADDITIONALDET"," ");
define("_EDITORREVIEW"," ");
define("_REPORTBROKEN","    ");
define("_AND","");
define("_INDB","  ");
define("_INSTRUCTIONS","");
define("_USERANDIP","           .");
define("_LDESCRIPTION",": (  255 )");
define("_LASTWEEK"," ");
define("_LAST30DAYS"," 30 ");
define("_1WEEK","");
define("_2WEEKS","");
define("_30DAYS","30 ");
define("_SHOW","");
define("_DAYS","/");
define("_ADDEDON","");
define("_RATING","");
define("_DETAILS","");
define("_OF","");
define("_TVOTESREQ","  ");
define("_SHOWTOP"," ");
define("_MOSTPOPULAR","  - ");
define("_OFALL"," ");
define("_POPULARITY","");
define("_SELECTPAGE"," ");
define("_MAIN","");
define("_NEWTODAY"," ");
define("_NEWLAST3DAYS","   ");
define("_NEWTHISWEEK","  ");
define("_POPULARITY1"," (   )");
define("_POPULARITY2"," (   )");
define("_TITLEAZ"," (  )");
define("_TITLEZA"," (  )");
define("_RATING1"," (    )");
define("_RATING2"," (    )");
define("_SEARCHRESULTS4"," ");
define("_USUBCATEGORIES"," ");
define("_TRY2SEARCH"," ");
define("_INOTHERSENGINES","   ");
define("_EDITORIAL","");
define("_EDITORIALBY"," ");
define("_NOEDITORIAL","     .");
define("_RATETHISSITE","  ");
define("_ISTHISYOURSITE","  ߿");
define("_ALLOWTORATE","    !");
define("_OVERALLRATING"," ");
define("_TOTALOF","");
define("_USER","");
define("_USERAVGRATING","  ");
define("_NUMRATINGS","# ");
define("_REGISTEREDUSERS"," ");
define("_NUMBEROFRATINGS"," ");
define("_NOREGUSERSVOTES","     ");
define("_BREAKDOWNBYVAL","  ");
define("_LTOTALVOTES"," ");
define("_HIGHRATING"," ");
define("_LOWRATING"," ");
define("_NUMOFCOMMENTS"," ");
define("_WEIGHNOTE","* :         ");
define("_NOUNREGUSERSVOTES","     ");
define("_WEIGHOUTNOTE","* :      ");
define("_NOOUTSIDEVOTES","   ");
define("_OUTSIDEVOTERS","  ");
define("_UNREGISTEREDUSERS","  ");
define("_PROMOTEYOURSITE","  ");
define("_PROMOTE01","      .              .     :");
define("_TEXTLINK"," ");
define("_HTMLCODE1","     :");
define("_THENUMBER","");
define("_IDREFER","          $sitename.     .");
define("_BUTTONLINK"," ");
define("_RATEIT","  !");
define("_HTMLCODE2","    :");
define("_REMOTEFORM","  ");
define("_VOTE4THISSITE","  !");
define("_HTMLCODE3","               .               .   :");
define("_PROMOTE05","       ");
define("_STAFF"," ");
define("_THANKSBROKEN","     .");
define("_SECURITYBROKEN","           .");
define("_THANKSFORINFO","   .");
define("_LOOKTOREQUEST","    .");
define("_SENDREQUEST"," ");
define("_THANKSTOTAKETIME","    ");
define("_RETURNTO"," ");
define("_RATENOTE1","       .");
define("_RATENOTE2","   1 - 10.  1   10  .");
define("_RATENOTE3","     .              .");
define("_RATENOTE5","      .");
define("_YOUAREREGGED","     .");
define("_FEELFREE2ADD","     .");
define("_YOUARENOTREGGED","         .");
define("_IFYOUWEREREG","        .");
define("_TITLE","");
define("_MODIFY","");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b-%Y");
define("_AUTHORNAME","Author's Name");
define("_AUTHOREMAIL","Author's Email");
define("_DOWNLOADNAME","Program Name");
define("_ADDTHISFILE","Add this file");
define("_INBYTES","in bytes");
define("_RATERESOURCE","Rate Resource");
define("_DSUBMITONCE","Submit a unique download only once.");
define("_DPOSTPENDING","All downloads are posted pending verification.");
define("_DTOTALFORLAST","Total new downloads for last");
define("_DBESTRATED","Best Rated Downloads - Top");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Downloads/language/lang-arabic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","");
define("_PREVIOUS"," ");
define("_NEXT"," ");
define("_CATEGORY","");
define("_CATEGORIES","");
define("_LVOTES","");
define("_TOTALVOTES"," :");
define("_THEREARE"," ");
define("_NOMATCHES","   ");
define("_SCOMMENTS","");
define("_UNKNOWN"," ");
define("_DOWNLOADS","");
define("_FILESIZE"," ");
define("_VERSION","");
define("_DESCRIPTION","");
define("_AUTHOR"," ");
define("_HOMEPAGE","");
define("_DOWNLOADNOW","  !");
define("_FILEURL"," ");
define("_ADDDOWNLOAD"," ");
define("_DOWNLOADSMAIN","  ");
define("_DOWNLOADCOMMENTS","  ");
define("_DOWNLOADSMAINCAT","  ");
define("_ADDADOWNLOAD","  ");
define("_DOWNLOADSNOTUSER1","         .");
define("_DOWNLOADSNOTUSER2","      .");
define("_DOWNLOADSNOTUSER3","   .");
define("_DOWNLOADSNOTUSER4","       ڿ");
define("_DOWNLOADSNOTUSER5","       ,");
define("_DOWNLOADSNOTUSER6","          .");
define("_DOWNLOADSNOTUSER7","     .");
define("_DOWNLOADSNOTUSER8","<a href=\"modules.php?name=Your_Account\"> </a>");
define("_DOWNLOADALREADYEXT",":       !");
define("_DOWNLOADNOTITLE",":      !");
define("_DOWNLOADNOURL",":    !");
define("_DOWNLOADNODESC",":    !");
define("_DOWNLOADRECEIVED","!     ");
define("_CHECKFORIT","   .      .");
define("_NEWDOWNLOADS"," ");
define("_TOTALNEWDOWNLOADS","  ");
define("_TRATEDDOWNLOADS","  ");
define("_SORTDOWNLOADSBY","  ");
define("_DOWNLOADPROFILE"," ");
define("_DOWNLOADRATINGDET","  ");
define("_EDITTHISDOWNLOAD","  ");
define("_DOWNLOADRATING"," ");
define("_PROMOTE02","One way to download to the rating form is through a simple text download:");
define("_PROMOTE03","If you're looking for a little more than a basic text download, you may wish to use a small button download:");
define("_PROMOTE04","If you cheat on this, we'll remove your download. Having said that, here is what the current remote rating form looks like.");
define("_DOWNLOADVOTE","!");
define("_REQUESTDOWNLOADMOD","Request Download Modification");
define("_DOWNLOADID","Download ID");
define("_DATE","");
define("_TO","");
define("_NEW","");
define("_POPULAR","");
define("_TOPRATED"," ");
define("_ADDITIONALDET"," ");
define("_EDITORREVIEW"," ");
define("_REPORTBROKEN","    ");
define("_AND","");
define("_INDB","  ");
define("_INSTRUCTIONS","");
define("_USERANDIP","           .");
define("_LDESCRIPTION",": (  255 )");
define("_LASTWEEK"," ");
define("_LAST30DAYS"," 30 ");
define("_1WEEK","");
define("_2WEEKS","");
define("_30DAYS","30 ");
define("_SHOW","");
define("_DAYS","/");
define("_ADDEDON","");
define("_RATING","");
define("_DETAILS","");
define("_OF","");
define("_TVOTESREQ","  ");
define("_SHOWTOP"," ");
define("_MOSTPOPULAR","  - ");
define("_OFALL"," ");
define("_POPULARITY","");
define("_SELECTPAGE"," ");
define("_MAIN","");
define("_NEWTODAY"," ");
define("_NEWLAST3DAYS","   ");
define("_NEWTHISWEEK","  ");
define("_POPULARITY1"," (   )");
define("_POPULARITY2"," (   )");
define("_TITLEAZ"," (  )");
define("_TITLEZA"," (  )");
define("_RATING1"," (    )");
define("_RATING2"," (    )");
define("_SEARCHRESULTS4"," ");
define("_USUBCATEGORIES"," ");
define("_TRY2SEARCH"," ");
define("_INOTHERSENGINES","   ");
define("_EDITORIAL","");
define("_EDITORIALBY"," ");
define("_NOEDITORIAL","     .");
define("_RATETHISSITE","  ");
define("_ISTHISYOURSITE","  ߿");
define("_ALLOWTORATE","    !");
define("_OVERALLRATING"," ");
define("_TOTALOF","");
define("_USER","");
define("_USERAVGRATING","  ");
define("_NUMRATINGS","# ");
define("_REGISTEREDUSERS"," ");
define("_NUMBEROFRATINGS"," ");
define("_NOREGUSERSVOTES","     ");
define("_BREAKDOWNBYVAL","  ");
define("_LTOTALVOTES"," ");
define("_HIGHRATING"," ");
define("_LOWRATING"," ");
define("_NUMOFCOMMENTS"," ");
define("_WEIGHNOTE","* :         ");
define("_NOUNREGUSERSVOTES","     ");
define("_WEIGHOUTNOTE","* :      ");
define("_NOOUTSIDEVOTES","   ");
define("_OUTSIDEVOTERS","  ");
define("_UNREGISTEREDUSERS","  ");
define("_PROMOTEYOURSITE","  ");
define("_PROMOTE01","      .              .     :");
define("_TEXTLINK"," ");
define("_HTMLCODE1","     :");
define("_THENUMBER","");
define("_IDREFER","          $sitename.     .");
define("_BUTTONLINK"," ");
define("_RATEIT","  !");
define("_HTMLCODE2","    :");
define("_REMOTEFORM","  ");
define("_VOTE4THISSITE","  !");
define("_HTMLCODE3","               .               .   :");
define("_PROMOTE05","       ");
define("_STAFF"," ");
define("_THANKSBROKEN","     .");
define("_SECURITYBROKEN","           .");
define("_THANKSFORINFO","   .");
define("_LOOKTOREQUEST","    .");
define("_SENDREQUEST"," ");
define("_THANKSTOTAKETIME","    ");
define("_RETURNTO"," ");
define("_RATENOTE1","       .");
define("_RATENOTE2","   1 - 10.  1   10  .");
define("_RATENOTE3","     .              .");
define("_RATENOTE5","      .");
define("_YOUAREREGGED","     .");
define("_FEELFREE2ADD","     .");
define("_YOUARENOTREGGED","         .");
define("_IFYOUWEREREG","        .");
define("_TITLE","");
define("_MODIFY","");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b-%Y");
define("_AUTHORNAME","Author's Name");
define("_AUTHOREMAIL","Author's Email");
define("_DOWNLOADNAME","Program Name");
define("_ADDTHISFILE","Add this file");
define("_INBYTES","in bytes");
define("_RATERESOURCE","Rate Resource");
define("_DSUBMITONCE","Submit a unique download only once.");
define("_DPOSTPENDING","All downloads are posted pending verification.");
define("_DTOTALFORLAST","Total new downloads for last");
define("_DBESTRATED","Best Rated Downloads - Top");

?>
